@@ -4,6 +4,8 @@ compile_error!("genson-core requires panic=unwind to catch genson-rs panics. Set
 pub mod genson_rs;
 #[cfg(feature = "avro")]
 pub mod normalise;
+#[cfg(feature = "parquet")]
+pub mod parquet;
 pub mod schema;
 
 // Re-export commonly used items
